@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Optional, Protocol
+from typing import Protocol
 
 from attr import attrs
 from pydantic import BaseModel, FilePath
@@ -24,7 +24,7 @@ class GraphicsPageProtocol(Protocol):
         ...
 
 
-@attrs(slots=True, auto_attribs=True, frozen=True, eq=True, hash=True)
+@attrs(slots=True, auto_attribs=True, frozen=True, eq=True, hash=False)
 class GraphicsPage:
     """
     A representation of a single page of graphics inside the ROM, that uses ``attrs`` to create a
@@ -39,12 +39,16 @@ class GraphicsPage:
     """
 
     index: int
-    path: Optional[Path] = None
+    path: Path | None = None
 
     @property
     def offset(self) -> int:
         return ROM().header.program_size + self.index * CHR_ROM_SEGMENT_SIZE + INESHeader.INES_HEADER_SIZE
 
+    def __hash__(self) -> int:
+        # We will assume that the path is the same most of the time to make hashing faster.
+        return self.index
+
     def __bytes__(self) -> bytes:
         if self.path is None:
             return bytes(ROM().bulk_read(CHR_ROM_SEGMENT_SIZE, self.offset, is_graphics=True))
@@ -65,7 +69,7 @@ class PydanticGraphicsPage(BaseModel):
     """
 
     index: int
-    path: Optional[FilePath]
+    path: FilePath | None
 
     def to_graphics_page(self) -> GraphicsPageProtocol:
         return GraphicsPage(self.index, self.path)
