@@ -1,10 +1,10 @@
 from PySide6.QtCore import QRect, QSize
 from PySide6.QtGui import QColor, QImage, QPainter, Qt
 
+from foundry.core.geometry import Point
 from foundry.core.graphics_page.GraphicsPage import GraphicsPage
 from foundry.core.graphics_set.GraphicsSet import GraphicsSet, GraphicsSetProtocol
 from foundry.core.palette.PaletteGroup import MutablePaletteGroup
-from foundry.core.point.Point import Point, PointProtocol
 from foundry.game.EnemyDefinitions import (
     EnemyDefinition,
     GeneratorType,
@@ -181,11 +181,11 @@ class EnemyObject(ObjectLike):
         self.position = Point(self.position.x + dx, self.position.y + dy)
 
     @property
-    def position(self) -> PointProtocol:
+    def position(self) -> Point:
         return self.enemy.position
 
     @position.setter
-    def position(self, position: PointProtocol):
+    def position(self, position: Point):
         self.enemy.position = Point(max(0, position.x), max(0, position.y))
 
     @property
