@@ -1,6 +1,6 @@
 from PySide6.QtCore import QRect
 
-from foundry.core.point.Point import Point, PointProtocol
+from foundry.core.geometry import Point
 from foundry.game.Definitions import Definition
 from foundry.game.gfx.objects.ObjectLike import ObjectLike
 
@@ -153,11 +153,11 @@ class MapObject(ObjectLike):
         return Definition(description="Map Object", warnings=[])
 
     @property
-    def position(self) -> PointProtocol:
+    def position(self) -> Point:
         return Point(self.x_position, self.y_position)
 
     @position.setter
-    def position(self, position: PointProtocol):
+    def position(self, position: Point):
         self.x_position, self.y_position = position.x, position.y
         self.rect = QRect(position.x, position.y, 1, 1)
 
