@@ -1,7 +1,7 @@
 import logging
 import os
 from collections.abc import Callable
-from typing import Optional, Protocol, Tuple
+from typing import Protocol
 
 from PySide6.QtCore import QPoint
 from PySide6.QtGui import QAction, QPixmap, Qt
@@ -14,9 +14,14 @@ from foundry.game.gfx.objects.LevelObject import LevelObject
 from foundry.game.level.Level import Level, get_level_name_suggestion
 from foundry.game.level.LevelControlled import LevelControlled
 from foundry.game.level.LevelRef import LevelRef
+from foundry.game.level.util import get_level_index
 from foundry.gui.AutoScrollEditor import AutoScrollEditor
 from foundry.gui.BlockViewer import BlockViewerController as BlockViewer
-from foundry.gui.HeaderEditor import HeaderEditor
+from foundry.gui.HeaderEditor import (
+    HeaderEditor,
+    header_state_to_level_header,
+    level_to_header_state,
+)
 from foundry.gui.JumpEditor import JumpEditor
 from foundry.gui.LevelSelector import LevelSelector
 from foundry.gui.LevelView import undoable
@@ -32,7 +37,7 @@ def require_safe_to_change(function: Callable):
 
 
 class LevelSelectorController(Protocol):
-    last_level: Optional[tuple[int, int]]
+    last_level: tuple[int, int] | None
 
 
 class LevelController:
@@ -83,12 +88,12 @@ class LevelController:
         object_set = self.level_ref.level.next_area_object_set
 
         self.update_level(
-            f"Level {get_level_name_suggestion(level_address + 9)}", level_address, enemy_address, object_set
+            f"PydanticLevel {get_level_name_suggestion(level_address + 9)}", level_address, enemy_address, object_set
         )
 
     @require_safe_to_change
     def on_select(self):
-        selector = LevelSelector(self.parent, start_level=self.level_selector_last_level)
+        selector = LevelSelector(self.parent, ROM().settings, start_level=self.level_selector_last_level)
 
         if QDialog.Accepted == selector.exec():
             self.level_selector_last_level = selector.current_level_index
@@ -186,7 +191,7 @@ class LevelController:
             self.parent.context_menu.set_copied_objects(selected)
 
     @undoable
-    def paste(self, x: Optional[int] = None, y: Optional[int] = None):
+    def paste(self, x: int | None = None, y: int | None = None):
         self.parent.level_view.paste_objects_at(self.parent.context_menu.get_copied_objects(), x, y)
 
     def select_all(self):
@@ -222,7 +227,7 @@ class LevelController:
             self.parent.jump_list.item(index).setText(str(jump))
 
     @undoable
-    def place_object_from_dropdown(self, pos: Tuple[int, int]) -> None:
+    def place_object_from_dropdown(self, pos: tuple[int, int]) -> None:
         # the dropdown is synchronized with the toolbar, so it doesn't matter where to take it from
         level_object = self.parent.object_dropdown.currentData(Qt.UserRole)
 
@@ -294,8 +299,28 @@ class LevelController:
         self.parent.level_view.update()
 
     def display_header_editor(self):
-        header_editor = HeaderEditor(self.parent, self.level_ref)  # type: ignore
-        header_editor.tab_widget.setCurrentIndex(3)
+        header_editor = HeaderEditor(
+            self.parent, level_to_header_state(self.level_ref.level, ROM().settings), ROM().settings  # type: ignore
+        )
+        header_editor.current_page = 3
+
+        def update_level_header(state):
+            rom = ROM()
+
+            self.level_ref.level.header_bytes = header_state_to_level_header(state)
+            self.level_ref.level.name = state.info.display_information.name
+            self.level_ref.level.object_size_on_disk = state.info.generator_size - 9
+            self.level_ref.level.enemy_size_on_disk = state.info.enemy_size
+            self.parent.setWindowTitle(self.title_suggestion)  # type: ignore
+            self.level_ref.level._parse_header()
+            levels = rom.settings.levels
+            index = get_level_index(levels, self.level_ref.level.object_offset, self.level_ref.level.enemy_offset)
+            levels[index] = state.info
+            rom._settings.levels = levels
+            ROM().settings = rom.settings
+            self.level_ref.data_changed.emit()
+
+        header_editor.state_changed.connect(update_level_header)
         header_editor.exec_()
 
     def display_jump_editor(self):
