@@ -1,5 +1,3 @@
-from typing import Optional
-
 from attr import attrs
 from PySide6.QtCore import QPoint, QRect, Signal, SignalInstance
 from PySide6.QtGui import (
@@ -13,9 +11,9 @@ from PySide6.QtGui import (
 from PySide6.QtWidgets import QLayout, QStatusBar, QToolBar, QWidget
 
 from foundry import icon
+from foundry.core.geometry import Point
 from foundry.core.graphics_set.GraphicsSet import GraphicsSet
 from foundry.core.palette.PaletteGroup import MutablePaletteGroup
-from foundry.core.point.Point import Point
 from foundry.game.gfx.drawable.Block import Block
 from foundry.gui.CustomChildWindow import CustomChildWindow
 from foundry.gui.PatternViewer import PatternViewerController as PatternViewer
@@ -40,7 +38,7 @@ class BlockEditorController(CustomChildWindow):
 
     def __init__(
         self,
-        parent: Optional[QWidget],
+        parent: QWidget | None,
         tsa_data: bytearray,
         block_index: int,
         graphics_set: GraphicsSet,
@@ -59,8 +57,8 @@ class BlockEditorController(CustomChildWindow):
 
         self.view.pattern_selected.connect(lambda values: self._on_pattern_selected(*values))
 
-        self.zoom_out_action = self.toolbar.addAction(icon("zoom-out.svg"), "Zoom Out")
-        self.zoom_in_action = self.toolbar.addAction(icon("zoom-in.svg"), "Zoom In")
+        self.zoom_out_action = self.toolbar.addAction(icon("zoom-out.png"), "Zoom Out")
+        self.zoom_in_action = self.toolbar.addAction(icon("zoom-in.png"), "Zoom In")
 
         def change_zoom(offset: int):
             self.view.zoom += offset
@@ -176,7 +174,7 @@ class BlockEditorView(QWidget):
 
     def __init__(
         self,
-        parent: Optional[QWidget],
+        parent: QWidget | None,
         tsa_data: bytearray,
         block_index: int,
         graphics_set: GraphicsSet,
@@ -211,8 +209,8 @@ class BlockEditorView(QWidget):
 
     def mouseReleaseEvent(self, event: QMouseEvent) -> None:
         pos = Point.from_qpoint(event.pos())
-        pos.x, pos.y = pos.x // (self.block_scale // 2), pos.y // (self.block_scale // 2)
-        self.pattern_selected.emit((pos.x, pos.y))
+        x, y = pos.x // (self.block_scale // 2), pos.y // (self.block_scale // 2)
+        self.pattern_selected.emit((x, y))
 
     def paintEvent(self, event: QPaintEvent):
         painter = QPainter(self)
