@@ -1,5 +1,4 @@
 from bisect import bisect_right
-from typing import List, Optional, Tuple, Union
 from warnings import warn
 
 from PySide6.QtCore import QMimeData, QPoint, QSize, Signal, SignalInstance
@@ -15,7 +14,7 @@ from PySide6.QtGui import (
 )
 from PySide6.QtWidgets import QSizePolicy, QToolTip, QWidget
 
-from foundry.core.point.Point import Point
+from foundry.core.geometry import Point
 from foundry.game.gfx.drawable.Block import Block
 from foundry.game.gfx.objects.EnemyItem import EnemyObject
 from foundry.game.gfx.objects.LevelObject import LevelObject
@@ -35,7 +34,7 @@ from foundry.game.level.WorldMap import WorldMap
 from foundry.gui.ContextMenu import ContextMenu
 from foundry.gui.LevelDrawer import LevelDrawer
 from foundry.gui.SelectionSquare import SelectionSquare
-from foundry.gui.settings import RESIZE_LEFT_CLICK, RESIZE_RIGHT_CLICK, SETTINGS
+from foundry.gui.settings import FileSettings, ResizeModes, UserSettings
 
 HIGHEST_ZOOM_LEVEL = 8  # on linux, at least
 LOWEST_ZOOM_LEVEL = 1 / 16  # on linux, but makes sense with 16x16 blocks
@@ -62,29 +61,31 @@ class LevelView(QWidget):
     objects_selected: SignalInstance = Signal(object)  # type: ignore
     object_created: SignalInstance = Signal(object)  # type: ignore
 
-    def __init__(self, parent: Optional[QWidget], level: LevelRef, context_menu: ContextMenu):
-        super(LevelView, self).__init__(parent)
+    user_settings: UserSettings
+
+    def __init__(
+        self,
+        parent: QWidget | None,
+        level: LevelRef,
+        context_menu: ContextMenu,
+        file_settings: FileSettings,
+        user_settings: UserSettings,
+    ):
+        super().__init__(parent)
 
         self.setSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
         self.setMouseTracking(True)
         self.setAcceptDrops(True)
 
+        self.file_settings = file_settings
+        self.user_settings = user_settings
+
         self.level_ref: LevelRef = level
         self.level_ref.data_changed.connect(self.update)
 
         self.context_menu = context_menu
 
-        self.level_drawer = LevelDrawer()
-
-        self.draw_grid = SETTINGS["draw_grid"]
-        self.draw_jumps = SETTINGS["draw_jumps"]
-        self.draw_expansions = SETTINGS["draw_expansion"]
-        self.draw_mario = SETTINGS["draw_mario"]
-        self.transparency = SETTINGS["block_transparency"]
-        self.draw_jumps_on_objects = SETTINGS["draw_jump_on_objects"]
-        self.draw_items_in_blocks = SETTINGS["draw_items_in_blocks"]
-        self.draw_invisible_items = SETTINGS["draw_invisible_items"]
-        self.draw_autoscroll = SETTINGS["draw_autoscroll"]
+        self.level_drawer = LevelDrawer(self.user_settings)
 
         self.zoom = 1
         self.block_length = Block.SIDE_LENGTH * self.zoom
@@ -107,10 +108,10 @@ class LevelView(QWidget):
         self.resizing_happened = False
 
         # dragged in from the object toolbar
-        self.currently_dragged_object: Optional[Union[LevelObject, EnemyObject]] = None
+        self.currently_dragged_object: LevelObject | EnemyObject | None = None
 
         self.setWhatsThis(
-            "<b>Level View</b><br/>"
+            "<b>PydanticLevel View</b><br/>"
             "This renders the level as it would appear in game plus additional information, that can be "
             "toggled in the View menu.<br/>"
             "It supports selecting multiple objects, moving, copy/pasting and resizing them using the "
@@ -125,75 +126,75 @@ class LevelView(QWidget):
 
     @property
     def transparency(self):
-        return self.level_drawer.transparency
+        return self.user_settings.block_transparency
 
     @transparency.setter
     def transparency(self, value):
-        self.level_drawer.transparency = value
+        self.user_settings.block_transparency = value
 
     @property
     def draw_grid(self):
-        return self.level_drawer.draw_grid
+        return self.user_settings.draw_grid
 
     @draw_grid.setter
     def draw_grid(self, value):
-        self.level_drawer.draw_grid = value
+        self.user_settings.draw_grid = value
 
     @property
     def draw_jumps(self):
-        return self.level_drawer.draw_jumps
+        return self.user_settings.draw_jumps
 
     @draw_jumps.setter
     def draw_jumps(self, value):
-        self.level_drawer.draw_jumps = value
+        self.user_settings.draw_jumps = value
 
     @property
     def draw_mario(self):
-        return self.level_drawer.draw_mario
+        return self.user_settings.draw_mario
 
     @draw_mario.setter
     def draw_mario(self, value):
-        self.level_drawer.draw_mario = value
+        self.user_settings.draw_mario = value
 
     @property
     def draw_expansions(self):
-        return self.level_drawer.draw_expansions
+        return self.user_settings.draw_expansion
 
     @draw_expansions.setter
     def draw_expansions(self, value):
-        self.level_drawer.draw_expansions = value
+        self.user_settings.draw_expansion = value
 
     @property
     def draw_jumps_on_objects(self):
-        return self.level_drawer.draw_jumps_on_objects
+        return self.user_settings.draw_jump_on_objects
 
     @draw_jumps_on_objects.setter
     def draw_jumps_on_objects(self, value):
-        self.level_drawer.draw_jumps_on_objects = value
+        self.user_settings.draw_jump_on_objects = value
 
     @property
     def draw_items_in_blocks(self):
-        return self.level_drawer.draw_items_in_blocks
+        return self.user_settings.draw_items_in_blocks
 
     @draw_items_in_blocks.setter
     def draw_items_in_blocks(self, value):
-        self.level_drawer.draw_items_in_blocks = value
+        self.user_settings.draw_items_in_blocks = value
 
     @property
     def draw_invisible_items(self):
-        return self.level_drawer.draw_invisible_items
+        return self.user_settings.draw_invisible_items
 
     @draw_invisible_items.setter
     def draw_invisible_items(self, value):
-        self.level_drawer.draw_invisible_items = value
+        self.user_settings.draw_invisible_items = value
 
     @property
     def draw_autoscroll(self):
-        return self.level_drawer.draw_autoscroll
+        return self.user_settings.draw_autoscroll
 
     @draw_autoscroll.setter
     def draw_autoscroll(self, value):
-        self.level_drawer.draw_autoscroll = value
+        self.user_settings.draw_autoscroll = value
 
     def mousePressEvent(self, event: QMouseEvent):
         pressed_button = event.button()
@@ -203,7 +204,7 @@ class LevelView(QWidget):
         elif pressed_button == Qt.RightButton:
             self._on_right_mouse_button_down(event)
         else:
-            return super(LevelView, self).mousePressEvent(event)
+            return super().mousePressEvent(event)
 
     def mouseMoveEvent(self, event: QMouseEvent):
         if self.mouse_mode == MODE_DRAG:
@@ -220,20 +221,20 @@ class LevelView(QWidget):
         elif self.selection_square.active:
             self._set_selection_end(event.position().toPoint())
 
-        elif SETTINGS["resize_mode"] == RESIZE_LEFT_CLICK:
+        elif self.user_settings.resize_mode == ResizeModes.RESIZE_LEFT_CLICK:
             self._set_cursor_for_position(event)
 
         x, y = event.position().toPoint().toTuple()
 
         object_under_cursor = self.object_at(x, y)
 
-        if SETTINGS["object_tooltip_enabled"] and object_under_cursor is not None:
+        if self.user_settings.object_tooltip_enabled and object_under_cursor is not None:
             self.setToolTip(str(object_under_cursor))
         else:
             self.setToolTip("")
             QToolTip.hideText()
 
-        return super(LevelView, self).mouseMoveEvent(event)
+        return super().mouseMoveEvent(event)
 
     def _set_cursor_for_position(self, event: QMouseEvent):
         level_object = self.object_at(*event.position().toTuple())
@@ -264,9 +265,7 @@ class LevelView(QWidget):
         if self.mouse_mode not in RESIZE_MODES:
             self.setCursor(Qt.ArrowCursor)
 
-    def _cursor_on_edge_of_object(
-        self, level_object: Union[LevelObject, EnemyObject], pos: QPoint, edge_width: int = 4
-    ):
+    def _cursor_on_edge_of_object(self, level_object: LevelObject | EnemyObject, pos: QPoint, edge_width: int = 4):
         right = (level_object.get_rect().left() + level_object.get_rect().width()) * self.block_length
         bottom = (level_object.get_rect().top() + level_object.get_rect().height()) * self.block_length
 
@@ -291,10 +290,10 @@ class LevelView(QWidget):
         elif released_button == Qt.RightButton:
             self._on_right_mouse_button_up(event)
         else:
-            super(LevelView, self).mouseReleaseEvent(event)
+            super().mouseReleaseEvent(event)
 
     def wheelEvent(self, event: QWheelEvent):
-        if SETTINGS["object_scroll_enabled"]:
+        if self.user_settings.object_scroll_enabled:
             x, y = event.position().toPoint().toTuple()
 
             obj_under_cursor = self.object_at(x, y)
@@ -314,7 +313,7 @@ class LevelView(QWidget):
 
             return True
         else:
-            super(LevelView, self).wheelEvent(event)
+            super().wheelEvent(event)
             return False
 
     @undoable
@@ -333,7 +332,7 @@ class LevelView(QWidget):
 
     def sizeHint(self) -> QSize:
         if not self.level_ref:
-            return super(LevelView, self).sizeHint()
+            return super().sizeHint()
         else:
             width, height = self.level_ref.level.size
 
@@ -342,7 +341,7 @@ class LevelView(QWidget):
     def update(self):
         self.resize(self.sizeHint())
 
-        super(LevelView, self).update()
+        super().update()
 
     def _on_right_mouse_button_down(self, event: QMouseEvent):
         if self.mouse_mode == MODE_DRAG:
@@ -353,7 +352,7 @@ class LevelView(QWidget):
 
         self.last_mouse_position = level_x, level_y
 
-        if self._select_objects_on_click(event) and SETTINGS["resize_mode"] == RESIZE_RIGHT_CLICK:
+        if self._select_objects_on_click(event) and self.user_settings.resize_mode == ResizeModes.RESIZE_RIGHT_CLICK:
             self._try_start_resize(MODE_RESIZE_DIAG, event)
 
     def _try_start_resize(self, resize_mode: int, event: QMouseEvent):
@@ -435,7 +434,7 @@ class LevelView(QWidget):
             if obj is not None:
                 edge = self._cursor_on_edge_of_object(obj, event.position().toPoint())
 
-                if SETTINGS["resize_mode"] == RESIZE_LEFT_CLICK and edge:
+                if self.user_settings.resize_mode == ResizeModes.RESIZE_LEFT_CLICK and edge:
 
                     self._try_start_resize(self._resize_mode_from_edge(edge), event)
                 else:
@@ -576,7 +575,7 @@ class LevelView(QWidget):
     def select_all(self):
         self.select_objects(self.level_ref.level.get_all_objects())
 
-    def _select_object(self, objects: Optional[list]):
+    def _select_object(self, objects: list | None):
         if objects is not None:
             self.select_objects(objects)
             self.objects_selected.emit(objects)
@@ -595,23 +594,23 @@ class LevelView(QWidget):
 
         self.level_ref.selected_objects = objects
 
-    def get_selected_objects(self) -> List[Union[LevelObject, EnemyObject]]:
+    def get_selected_objects(self) -> list[LevelObject | EnemyObject]:
         return self.level_ref.selected_objects
 
     def remove_selected_objects(self):
         for obj in self.level_ref.selected_objects:
             self.level_ref.level.remove_object(obj)
 
-    def scroll_to_objects(self, objects: List[LevelObject]):
+    def scroll_to_objects(self, objects: list[LevelObject]):
         if not objects:
             return
 
-        min_x = min([obj.position.x for obj in objects]) * self.block_length
-        min_y = min([obj.position.y for obj in objects]) * self.block_length
+        min_x = min(obj.position.x for obj in objects) * self.block_length
+        min_y = min(obj.position.y for obj in objects) * self.block_length
 
         self.parent().parent().ensureVisible(min_x, min_y)
 
-    def level_safe_to_save(self) -> Tuple[bool, str, str]:
+    def level_safe_to_save(self) -> tuple[bool, str, str]:
         is_safe = True
         reason = ""
         additional_info = ""
@@ -647,11 +646,11 @@ class LevelView(QWidget):
 
     def _cuts_into_other_enemies(self) -> str:
         if self.level_ref is None:
-            raise ValueError("Level is None")
+            raise ValueError("PydanticLevel is None")
 
         enemies_end = self.level_ref.level.enemies_end
 
-        levels_by_enemy_offset = sorted(Level.offsets, key=lambda level: level.enemy_pointer)
+        levels_by_enemy_offset = sorted(self.file_settings.levels, key=lambda level: level.enemy_pointer)
 
         level_index = bisect_right([level.enemy_pointer for level in levels_by_enemy_offset], enemies_end) - 1
 
@@ -666,7 +665,7 @@ class LevelView(QWidget):
 
     def _cuts_into_other_objects(self) -> str:
         if self.level_ref is None:
-            raise ValueError("Level is None")
+            raise ValueError("PydanticLevel is None")
 
         end_of_level_objects = self.level_ref.level.objects_end
 
@@ -689,7 +688,7 @@ class LevelView(QWidget):
     def add_jump(self):
         self.level_ref.level.add_jump()
 
-    def object_at(self, x: int, y: int) -> Optional[Union[LevelObject, EnemyObject]]:
+    def object_at(self, x: int, y: int) -> LevelObject | EnemyObject | None:
         """
         Returns an enemy or level object at the point. The x and y is relative to the View (for example, when you
         receive a mouse event) and will be converted into level coordinates internally.
@@ -703,7 +702,7 @@ class LevelView(QWidget):
 
         return self.level_ref.level.object_at(level_x, level_y)
 
-    def _to_level_point(self, screen_x: int, screen_y: int) -> Tuple[int, int]:
+    def _to_level_point(self, screen_x: int, screen_y: int) -> tuple[int, int]:
         level_x = screen_x // self.block_length
         level_y = screen_y // self.block_length
 
@@ -731,7 +730,7 @@ class LevelView(QWidget):
 
         self.level_ref.level.add_enemy(enemy_index, level_x, level_y, index)
 
-    def replace_object(self, obj: LevelObject, domain: int, obj_index: int, length: Optional[int]):
+    def replace_object(self, obj: LevelObject, domain: int, obj_index: int, length: int | None):
         self.remove_object(obj)
 
         new_obj = self.level_ref.level.add_object(
@@ -760,9 +759,9 @@ class LevelView(QWidget):
 
     def paste_objects_at(
         self,
-        paste_data: Tuple[List[Union[LevelObject, EnemyObject]], Tuple[int, int]],
-        x: Optional[int] = None,
-        y: Optional[int] = None,
+        paste_data: tuple[list[LevelObject | EnemyObject], tuple[int, int]],
+        x: int | None = None,
+        y: int | None = None,
     ):
         if x is None or y is None:
             level_x, level_y = self.last_mouse_position
@@ -831,7 +830,7 @@ class LevelView(QWidget):
         self.object_created.emit(level_object)
         self.level_ref.data_changed.emit()
 
-    def _object_from_mime_data(self, mime_data: QMimeData) -> Union[LevelObject, EnemyObject]:
+    def _object_from_mime_data(self, mime_data: QMimeData) -> LevelObject | EnemyObject:
         object_type, *object_bytes = mime_data.data("application/level-object")
 
         if object_type == b"\x00":
