@@ -5,7 +5,6 @@ import pathlib
 import shlex
 import subprocess
 import tempfile
-from typing import Optional
 
 from PySide6.QtCore import QSize
 from PySide6.QtGui import QAction, QCloseEvent, QKeySequence, QMouseEvent, QShortcut, Qt
@@ -35,8 +34,9 @@ from foundry.game.level.LevelManager import LevelManager
 from foundry.gui.AboutWindow import AboutDialog
 from foundry.gui.ContextMenu import CMAction
 from foundry.gui.LevelSelector import LevelSelector
+from foundry.gui.orb import Orb
 from foundry.gui.player_lives import PlayerLives
-from foundry.gui.settings import GUI_STYLE, SETTINGS, save_settings
+from foundry.gui.settings import GUILoader, UserSettings, load_gui_loader, save_settings
 from foundry.gui.SettingsDialog import POWERUPS, SettingsDialog
 from foundry.gui.util import setup_window
 from foundry.smb3parse.constants import (
@@ -51,7 +51,7 @@ ROM_FILE_FILTER = "ROM files (*.nes *.rom);;All files (*)"
 M3L_FILE_FILTER = "M3L files (*.m3l);;All files (*)"
 IMG_FILE_FILTER = "Screenshots (*.png);;All files (*)"
 
-with open(main_window_flags_path, "r") as data:
+with open(main_window_flags_path) as data:
     main_window_flags = json.loads(data.read())
 del data
 
@@ -75,50 +75,56 @@ MODE_RESIZE = 2
 
 
 class MainWindow(QMainWindow):
-    level_selector_last_level: Optional[tuple[int, int]]
+    level_selector_last_level: tuple[int, int] | None
 
-    def __init__(self, path_to_rom="", world=None, level=None):
-        super(MainWindow, self).__init__()
+    def __init__(
+        self,
+        path_to_rom="",
+        world=None,
+        level=None,
+        user_settings: UserSettings | None = None,
+        gui_loader: GUILoader | None = None,
+    ):
+        super().__init__()
 
         self.setWindowIcon(icon(main_window_flags["icon"]))
-        try:
-            GUI_STYLE[SETTINGS["gui_style"]](self)
-        except KeyError:
-            SETTINGS["gui_style"] = "LIGHT BLUE"
-            GUI_STYLE[SETTINGS["gui_style"]]
+        self.user_settings = UserSettings() if user_settings is None else user_settings
+        self.gui_loader = load_gui_loader() if gui_loader is None else gui_loader
 
-        setup_window(self, main_window_flags)
+        self.gui_loader.load_style(self.user_settings.gui_style)(self)
 
-        self.manager = LevelManager(self)
+        setup_window(self, main_window_flags, self.user_settings)
+
+        self.manager = LevelManager(self, self.user_settings)
         self.manager.on_enable()
 
         self.menu_toolbar = QToolBar("Menu Toolbar", self)
         self.menu_toolbar.setOrientation(Qt.Horizontal)
         self.menu_toolbar.setIconSize(QSize(20, 20))
 
-        self.menu_toolbar.addAction(icon("settings.svg"), "Editor Settings").triggered.connect(self._on_show_settings)
+        self.menu_toolbar.addAction(icon("settings.png"), "Editor Settings").triggered.connect(self._on_show_settings)
         self.menu_toolbar.addSeparator()
-        self.menu_toolbar.addAction(icon("folder.svg"), "Open ROM").triggered.connect(self.on_open_rom)
-        self.menu_toolbar_save_action = self.menu_toolbar.addAction(icon("save.svg"), "Save Level")
+        self.menu_toolbar.addAction(icon("folder.png"), "Open ROM").triggered.connect(self.on_open_rom)
+        self.menu_toolbar_save_action = self.menu_toolbar.addAction(icon("save.png"), "Save PydanticLevel")
         self.menu_toolbar_save_action.triggered.connect(self.on_save_rom)
         self.menu_toolbar.addSeparator()
 
-        self.undo_action = self.menu_toolbar.addAction(icon("rotate-ccw.svg"), "Undo Action")
+        self.undo_action = self.menu_toolbar.addAction(icon("rotate-ccw.png"), "Undo Action")
         self.undo_action.triggered.connect(self.manager.undo)
         self.undo_action.setEnabled(False)
-        self.redo_action = self.menu_toolbar.addAction(icon("rotate-cw.svg"), "Redo Action")
+        self.redo_action = self.menu_toolbar.addAction(icon("rotate-cw.png"), "Redo Action")
         self.redo_action.triggered.connect(self.manager.redo)
         self.redo_action.setEnabled(False)
 
         self.menu_toolbar.addSeparator()
-        play_action = self.menu_toolbar.addAction(icon("play-circle.svg"), "Play Level")
+        play_action = self.menu_toolbar.addAction(icon("play-circle.png"), "Play PydanticLevel")
         play_action.triggered.connect(self.on_play)
-        play_action.setWhatsThis("Opens an emulator with the current Level set to 1-1.\nSee Settings.")
+        play_action.setWhatsThis("Opens an emulator with the current PydanticLevel set to 1-1.\nSee Settings.")
         self.menu_toolbar.addSeparator()
-        self.menu_toolbar.addAction(icon("zoom-out.svg"), "Zoom Out").triggered.connect(self.manager.zoom_out)
-        self.menu_toolbar.addAction(icon("zoom-in.svg"), "Zoom In").triggered.connect(self.manager.zoom_in)
+        self.menu_toolbar.addAction(icon("zoom-out.png"), "Zoom Out").triggered.connect(self.manager.zoom_out)
+        self.menu_toolbar.addAction(icon("zoom-in.png"), "Zoom In").triggered.connect(self.manager.zoom_in)
         self.menu_toolbar.addSeparator()
-        header_action = self.menu_toolbar.addAction(icon("tool.svg"), "Edit Level Header")
+        header_action = self.menu_toolbar.addAction(icon("tool.png"), "Edit PydanticLevel Header")
         header_action.triggered.connect(self.manager.display_header_editor)
         header_action.setWhatsThis(
             "<b>Header Editor</b><br/>"
@@ -127,7 +133,7 @@ class MainWindow(QMainWindow):
         )
 
         self.jump_destination_action = self.menu_toolbar.addAction(
-            icon("arrow-right-circle.svg"), "Go to Jump Destination"
+            icon("arrow-right-circle.png"), "Go to Jump Destination"
         )
         self.jump_destination_action.triggered.connect(self.manager.warp_to_alternative)
         self.jump_destination_action.setWhatsThis(
@@ -138,11 +144,11 @@ class MainWindow(QMainWindow):
 
         whats_this_action = QWhatsThis.createAction()
         whats_this_action.setWhatsThis("Click on parts of the editor, to receive help information.")
-        whats_this_action.setIcon(icon("help-circle.svg"))
+        whats_this_action.setIcon(icon("help-circle.png"))
         whats_this_action.setText("Starts 'What's this?' mode")
         self.menu_toolbar.addAction(whats_this_action)
 
-        self.warning_action = self.menu_toolbar.addAction(icon("alert-triangle.svg"), "Warning Panel")
+        self.warning_action = self.menu_toolbar.addAction(icon("alert-triangle.png"), "Warning Panel")
         self.warning_action.setWhatsThis("Shows a list of warnings.")
         self.warning_action.setDisabled(True)
         self.warning_action.triggered.connect(self.manager.display_warnings)
@@ -170,7 +176,7 @@ class MainWindow(QMainWindow):
         self.showMaximized()
 
     def _on_show_settings(self):
-        SettingsDialog(self).exec_()
+        SettingsDialog(self, user_settings=self.user_settings, gui_loader=self.gui_loader).exec_()
 
     @staticmethod
     def _save_auto_rom():
@@ -199,7 +205,7 @@ class MainWindow(QMainWindow):
 
     def _load_auto_save(self):
         # rom already loaded
-        with open(auto_save_level_data_path, "r") as level_data_file:
+        with open(auto_save_level_data_path) as level_data_file:
             json_data = level_data_file.read()
 
             object_set_number, level_offset, enemy_offset, base64_data = json.loads(json_data)
@@ -251,15 +257,15 @@ class MainWindow(QMainWindow):
 
         temp_rom.write(
             Title_PrepForWorldMap - 0x8,
-            bytes([SETTINGS["default_starting_world"] - 1]),
+            bytes([self.user_settings.default_starting_world - 1]),
         )
 
         temp_rom.save_to(str(path_to_temp_rom))
 
-        arguments = SETTINGS["instaplay_arguments"].replace("%f", str(path_to_temp_rom))
+        arguments = self.user_settings.instaplay_arguments.replace("%f", str(path_to_temp_rom))
         arguments = shlex.split(arguments, posix=False)
 
-        emu_path = pathlib.Path(SETTINGS["instaplay_emulator"])
+        emu_path = pathlib.Path(self.user_settings.instaplay_emulator)
 
         if emu_path.is_absolute():
             if emu_path.exists():
@@ -270,7 +276,7 @@ class MainWindow(QMainWindow):
                 )
                 return
         else:
-            emulator = SETTINGS["instaplay_emulator"]
+            emulator = self.user_settings.instaplay_emulator
 
         try:
             subprocess.run([emulator, *arguments])
@@ -287,7 +293,7 @@ class MainWindow(QMainWindow):
 
     def _put_current_level_to_level_1_1(self, rom) -> bool:
         # load world data
-        world = SMB3World.from_world_number(rom, SETTINGS["default_starting_world"])
+        world = SMB3World.from_world_number(rom, self.user_settings.default_starting_world)
 
         # find point of "level 1" tile in world map
         for position in world.gen_positions():
@@ -303,7 +309,7 @@ class MainWindow(QMainWindow):
             QMessageBox.critical(
                 self,
                 "Couldn't place level",
-                "The Level is not part of the rom yet (M3L?). Try saving it into the ROM first.",
+                "The PydanticLevel is not part of the rom yet (M3L?). Try saving it into the ROM first.",
             )
             return False
 
@@ -323,8 +329,8 @@ class MainWindow(QMainWindow):
         world.replace_level_at_position((layout_address, enemy_address - 1, object_set_number), position)
 
     def _set_default_powerup(self, rom) -> bool:
-        *_, powerup, hasPWing = POWERUPS[SETTINGS["default_powerup"]]
-        hasStar = SETTINGS["default_power_has_star"]
+        *_, powerup, hasPWing = POWERUPS[self.user_settings.default_powerup]
+        hasStar = self.user_settings.default_power_has_star
         nop = 0xEA
 
         rom.write(Title_PrepForWorldMap - 0x4, bytes([nop, nop, nop]))
@@ -399,7 +405,7 @@ class MainWindow(QMainWindow):
     def update_title(self):
         self.setWindowTitle(self.manager.title_suggestion if self.manager.enabled else "SMB3Foundry")
 
-    def on_open_rom(self, path_to_rom="", world: Optional[int] = None, level: Optional[int] = None) -> bool:
+    def on_open_rom(self, path_to_rom="", world: int | None = None, level: int | None = None) -> bool:
         if not self.safe_to_change():
             return False
 
@@ -422,7 +428,7 @@ class MainWindow(QMainWindow):
                 else:
                     self.manager.on_select()
             return True
-        except IOError as exp:
+        except OSError as exp:
             QMessageBox.warning(self, type(exp).__name__, f"Cannot open file '{path_to_rom}'.")
             return False
 
@@ -441,7 +447,7 @@ class MainWindow(QMainWindow):
             with open(pathname, "rb") as m3l_file:
 
                 m3l_data = bytearray(m3l_file.read())
-        except IOError as exp:
+        except OSError as exp:
             QMessageBox.warning(self, type(exp).__name__, f"Cannot open file '{pathname}'.")
 
             return False
@@ -575,7 +581,7 @@ class MainWindow(QMainWindow):
             ROM().save_to_file(pathname, set_new_path)
 
             self._save_auto_rom()
-        except IOError as exp:
+        except OSError as exp:
             QMessageBox.warning(self, f"{type(exp).__name__}", f"Cannot save ROM data to file '{pathname}'.")
 
     def on_save_m3l(self, _):
@@ -599,7 +605,7 @@ class MainWindow(QMainWindow):
         try:
             with open(pathname, "wb") as m3l_file:
                 m3l_file.write(m3l_bytes)
-        except IOError as exp:
+        except OSError as exp:
             QMessageBox.warning(self, type(exp).__name__, f"Couldn't save level to '{pathname}'.")
 
     def on_check_for_update(self):
@@ -617,7 +623,7 @@ class MainWindow(QMainWindow):
         if current_version != latest_version:
             latest_release_url = f"{releases_link}/tag/{latest_version}"
 
-            go_to_github_button = QPushButton(icon("external-link.svg"), "Go to latest release")
+            go_to_github_button = QPushButton(icon("external-link.png"), "Go to latest release")
             go_to_github_button.clicked.connect(lambda: open_url(latest_release_url))
 
             info_box = QMessageBox(
@@ -674,9 +680,9 @@ class MainWindow(QMainWindow):
         if item_id not in CHECKABLE_MENU:
             return
         setattr(self.level_view, CHECKABLE_MENU[item_id]["attribute"], checked)
-        SETTINGS[CHECKABLE_MENU[item_id]["name"]] = checked
+        setattr(self.user_settings, CHECKABLE_MENU[item_id]["name"], checked)
 
-        save_settings()
+        save_settings(self.user_settings)
 
     def open_level_selector(self, _):
         self.manager.on_select()
@@ -694,6 +700,10 @@ class MainWindow(QMainWindow):
         """Shows the Player Lives UI"""
         PlayerLives(self)
 
+    def on_orb_options(self, _):
+        """Shows the Orb Options UI"""
+        Orb(self)
+
     def on_palette_viewer(self, _):
         self.manager.display_palette_viewer()
 
@@ -724,4 +734,4 @@ class MainWindow(QMainWindow):
         auto_save_m3l_path.unlink(missing_ok=True)
         auto_save_level_data_path.unlink(missing_ok=True)
 
-        super(MainWindow, self).closeEvent(event)
+        super().closeEvent(event)
