@@ -1,5 +1,3 @@
-from typing import Optional
-
 from attr import attrs
 from PySide6.QtCore import QPoint, QRect, Signal, SignalInstance
 from PySide6.QtGui import (
@@ -15,10 +13,10 @@ from PySide6.QtGui import (
 from PySide6.QtWidgets import QLayout, QStatusBar, QToolBar, QWidget
 
 from foundry import icon
+from foundry.core.geometry import Point
 from foundry.core.graphics_set.GraphicsSet import GraphicsSet
 from foundry.core.palette import NESPalette
 from foundry.core.palette.PaletteGroup import MutablePaletteGroup
-from foundry.core.point.Point import Point
 from foundry.game.gfx.drawable import MASK_COLOR
 from foundry.game.gfx.drawable.Tile import Tile
 from foundry.gui.CustomChildWindow import CustomChildWindow
@@ -40,7 +38,7 @@ class PatternViewerController(CustomChildWindow):
 
     def __init__(
         self,
-        parent: Optional[QWidget],
+        parent: QWidget | None,
         graphics_set: GraphicsSet,
         palette_group: MutablePaletteGroup,
         palette_index: int,
@@ -54,8 +52,8 @@ class PatternViewerController(CustomChildWindow):
 
         self.view.pattern_selected.connect(self.pattern_selected.emit)
 
-        self.zoom_out_action = self.toolbar.addAction(icon("zoom-out.svg"), "Zoom Out")
-        self.zoom_in_action = self.toolbar.addAction(icon("zoom-in.svg"), "Zoom In")
+        self.zoom_out_action = self.toolbar.addAction(icon("zoom-out.png"), "Zoom Out")
+        self.zoom_in_action = self.toolbar.addAction(icon("zoom-in.png"), "Zoom In")
 
         def change_zoom(offset: int):
             self.view.zoom += offset
@@ -116,7 +114,7 @@ class PatternViewerView(QWidget):
 
     def __init__(
         self,
-        parent: Optional[QWidget],
+        parent: QWidget | None,
         graphics_set: GraphicsSet,
         palette_group: MutablePaletteGroup,
         palette_index: int,
@@ -152,7 +150,7 @@ class PatternViewerView(QWidget):
 
     def mouseMoveEvent(self, event: QMouseEvent):
         pos = Point.from_qpoint(event.pos())
-        pos.x, pos.y = pos.x // self.pattern_scale, pos.y // self.pattern_scale
+        pos = pos // Point(self.pattern_scale, self.pattern_scale)
 
         dec_index = pos.y * self.PATTERNS_PER_ROW + pos.x
         hex_index = hex(dec_index).upper().replace("X", "x")
@@ -163,7 +161,7 @@ class PatternViewerView(QWidget):
 
     def mouseReleaseEvent(self, event: QMouseEvent) -> None:
         pos = Point.from_qpoint(event.pos())
-        pos.x, pos.y = pos.x // self.pattern_scale, pos.y // self.pattern_scale
+        pos = pos // Point(self.pattern_scale, self.pattern_scale)
 
         index = pos.y * self.PATTERNS_PER_ROW + pos.x
         self.pattern_selected.emit(index)
