@@ -1,11 +1,10 @@
-from typing import Optional
-
 from attr import attrs
 from PySide6.QtCore import Signal, SignalInstance
 from PySide6.QtGui import QCloseEvent
 from PySide6.QtWidgets import QHBoxLayout, QLayout, QStatusBar, QToolBar, QWidget
 
 from foundry import icon
+from foundry.core.geometry import Point
 from foundry.core.palette.PaletteGroup import MutablePaletteGroupProtocol
 from foundry.core.player_animations import ANIMATION_WIDTH
 from foundry.core.player_animations.PlayerAnimation import PlayerAnimation
@@ -13,7 +12,6 @@ from foundry.core.player_animations.util import (
     get_animations_palette_index,
     load_player_animation,
 )
-from foundry.core.point.Point import Point
 from foundry.core.sprites import SPRITE_SIZE
 from foundry.core.sprites.Sprite import Sprite, SpriteProtocol
 from foundry.core.sprites.SpriteGroup import SpriteGroup, SpriteGroupProtocol
@@ -38,7 +36,7 @@ class PlayerFrameEditorController(CustomChildWindow):
 
     def __init__(
         self,
-        parent: Optional[QWidget],
+        parent: QWidget | None,
         animation: PlayerAnimation,
         power_up_offsets: list[int],
         palette_group: MutablePaletteGroupProtocol,
@@ -50,7 +48,7 @@ class PlayerFrameEditorController(CustomChildWindow):
 
         self.model = PlayerFrameEditorModel(animation, power_up_offsets, palette_group, is_mario)
         self.view = PlayerFrameEditorView(self, self.sprite_groups, zoom)
-        self.sprite_viewer: Optional[SpriteViewer] = None
+        self.sprite_viewer: SpriteViewer | None = None
         self.sprite_viewer_index = 0
         self.setCentralWidget(self.view)
         self.toolbar = QToolBar(self)
@@ -59,8 +57,8 @@ class PlayerFrameEditorController(CustomChildWindow):
 
         self.view.clicked.connect(self._create_sprite_viewer)
 
-        self.zoom_out_action = self.toolbar.addAction(icon("zoom-out.svg"), "Zoom Out")
-        self.zoom_in_action = self.toolbar.addAction(icon("zoom-in.svg"), "Zoom In")
+        self.zoom_out_action = self.toolbar.addAction(icon("zoom-out.png"), "Zoom Out")
+        self.zoom_in_action = self.toolbar.addAction(icon("zoom-in.png"), "Zoom In")
 
         self.page_offset_spinner = Spinner(self, 0xFF)
         self.page_offset_spinner.setValue(animation.offset)
@@ -207,7 +205,7 @@ class PlayerFrameEditorView(QWidget):
 
     def __init__(
         self,
-        parent: Optional[QWidget],
+        parent: QWidget | None,
         sprite_groups: list[SpriteGroupProtocol],
         zoom: int = 2,
     ):
