@@ -1,15 +1,12 @@
-from typing import Optional
-
 from attr import attrs
 from PySide6.QtCore import Signal, SignalInstance
 from PySide6.QtGui import QCloseEvent, QMouseEvent, QPainter, QPaintEvent, QResizeEvent
 from PySide6.QtWidgets import QLayout, QStatusBar, QToolBar, QWidget
 
 from foundry import icon
+from foundry.core.geometry import Point, Size
 from foundry.core.graphics_set.GraphicsSet import GraphicsSetProtocol
 from foundry.core.palette.PaletteGroup import MutablePaletteGroupProtocol
-from foundry.core.point.Point import Point
-from foundry.core.size.Size import Size, SizeProtocol
 from foundry.core.sprites import SPRITE_SIZE
 from foundry.game.gfx.drawable.Sprite import Sprite
 from foundry.gui.CustomChildWindow import CustomChildWindow
@@ -31,7 +28,7 @@ class SpriteViewerController(CustomChildWindow):
 
     def __init__(
         self,
-        parent: Optional[QWidget],
+        parent: QWidget | None,
         graphics_set: GraphicsSetProtocol,
         palette_group: MutablePaletteGroupProtocol,
         palette_index: int,
@@ -47,8 +44,8 @@ class SpriteViewerController(CustomChildWindow):
 
         self.view.sprite_selected.connect(self.sprite_selected.emit)
 
-        self.zoom_out_action = self.toolbar.addAction(icon("zoom-out.svg"), "Zoom Out")
-        self.zoom_in_action = self.toolbar.addAction(icon("zoom-in.svg"), "Zoom In")
+        self.zoom_out_action = self.toolbar.addAction(icon("zoom-out.png"), "Zoom Out")
+        self.zoom_in_action = self.toolbar.addAction(icon("zoom-in.png"), "Zoom In")
 
         def change_zoom(offset: int):
             self.view.zoom += offset
@@ -110,7 +107,7 @@ class SpriteViewerView(QWidget):
 
     def __init__(
         self,
-        parent: Optional[QWidget],
+        parent: QWidget | None,
         graphics_set: GraphicsSetProtocol,
         palette_group: MutablePaletteGroupProtocol,
         palette_index: int,
@@ -141,12 +138,11 @@ class SpriteViewerView(QWidget):
         )
 
     @property
-    def sprite_size(self) -> SizeProtocol:
+    def sprite_size(self) -> Size:
         return Size(SPRITE_SIZE.width * self.zoom, SPRITE_SIZE.height * self.zoom)
 
     def mouseMoveEvent(self, event: QMouseEvent):
-        pos = Point.from_qpoint(event.pos())
-        pos.x, pos.y = pos.x // self.sprite_size.width, pos.y // self.sprite_size.height
+        pos = Point.from_qpoint(event.pos()) // Point(self.sprite_size.width, self.sprite_size.height)
 
         dec_index = pos.y * self.SPRITES_PER_ROW + pos.x
         hex_index = hex(dec_index).upper().replace("X", "x")
@@ -154,8 +150,7 @@ class SpriteViewerView(QWidget):
         self.mouse_moved.emit(pos.x, pos.y, dec_index, hex_index)
 
     def mouseReleaseEvent(self, event: QMouseEvent) -> None:
-        pos = Point.from_qpoint(event.pos())
-        pos.x, pos.y = pos.x // self.sprite_size.width, pos.y // self.sprite_size.height
+        pos = Point.from_qpoint(event.pos()) // Point(self.sprite_size.width, self.sprite_size.height)
 
         index = pos.y * self.SPRITES_PER_ROW + pos.x
         self.sprite_selected.emit(index)
