@@ -1,5 +1,4 @@
 from enum import Enum
-from typing import Optional
 
 from pydantic import BaseModel, Field
 from PySide6.QtGui import QColor
@@ -16,7 +15,7 @@ from PySide6.QtWidgets import (
 )
 
 from foundry import open_url
-from foundry.gui.settings import SETTINGS
+from foundry.gui.settings import UserSettings
 
 ID_PROP = "ID"
 
@@ -124,8 +123,8 @@ class Widget(BaseModel):
     """
 
     type: WidgetType
-    parent_attribute_name: Optional[str]
-    what_is_this: Optional[WhatIsThis]
+    parent_attribute_name: str | None
+    what_is_this: WhatIsThis | None
 
     class Config:
         use_enum_values = True  # Allow storing the enum as a string
@@ -144,7 +143,7 @@ class Button(Widget):
     """
 
     name: str = Field(default_factory=Field(""))
-    action: Optional[str]
+    action: str | None
 
 
 class Spinner(Widget):
@@ -167,10 +166,10 @@ class Spinner(Widget):
     """
 
     enabled: bool = Field(default_factor=Field(True))
-    minimum: Optional[int]
-    maximum: Optional[int]
+    minimum: int | None
+    maximum: int | None
     hexadecimal: bool = Field(default_factor=Field(False))
-    value_change_action: Optional[str]
+    value_change_action: str | None
 
 
 class WidgetCreator(BaseModel):
@@ -575,7 +574,7 @@ def setup_layout(parent: QWidget, flags: dict) -> QLayout:
     return layout
 
 
-def setup_widget_menu(widget: QMainWindow, flags):
+def setup_widget_menu(widget: QMainWindow, flags, user_settings: UserSettings):
     for menu_name, menu in flags["menu"].items():
         qmenu = QMenu(menu["name"])
         if menu.get("attribute", False):
@@ -617,9 +616,9 @@ def setup_widget_menu(widget: QMainWindow, flags):
                     action = qmenu.addAction(name)
                     action.setProperty(ID_PROP, option["id"])
                     action.setCheckable(True)
-                    action.setChecked(SETTINGS[option["name"]])
+                    action.setChecked(getattr(user_settings, option["name"]))
         widget.menuBar().addMenu(qmenu)
 
 
-def setup_window(widget: QMainWindow, flags):
-    setup_widget_menu(widget, flags)
+def setup_window(widget: QMainWindow, flags, user_settings: UserSettings):
+    setup_widget_menu(widget, flags, user_settings)
