@@ -1,8 +1,6 @@
 """ Implements a concretion of the CodeEdit interface with a byte payload.
 
 A single byte is the data type that is written to the specified address. """
-from typing import Optional
-
 from foundry.smb3parse.util.code_edit import CodeEdit
 from foundry.smb3parse.util.rom import Rom
 
@@ -13,7 +11,7 @@ class CodeEditByte(CodeEdit[int]):
     def __init__(self, rom: Rom, start_address: int, prefix: bytearray, postfix: bytearray):
         super().__init__(rom, start_address, 1, prefix, postfix)
 
-    def read(self) -> Optional[int]:
+    def read(self) -> int | None:
         """Reads the target byte out of the ROM.
 
         This reads the byte at the target code address if both the prefix and
